@@ -12,14 +12,45 @@
 ## usethis namespace: start
 #' @importFrom collections dict
 #' @importFrom collections queue
+#' @importFrom dplyr auto_copy
+#' @importFrom dplyr do
+#' @importFrom dplyr dplyr_col_modify
+#' @importFrom dplyr dplyr_reconstruct
+#' @importFrom dplyr dplyr_row_slice
+#' @importFrom dplyr funs
+#' @importFrom dplyr funs_
+#' @importFrom dplyr group_by
 #' @importFrom dplyr group_by_prepare
+#' @importFrom dplyr group_cols
+#' @importFrom dplyr group_data
 #' @importFrom dplyr group_indices
+#' @importFrom dplyr group_keys
+#' @importFrom dplyr group_map
+#' @importFrom dplyr group_modify
 #' @importFrom dplyr group_nest
+#' @importFrom dplyr group_rows
+#' @importFrom dplyr group_size
 #' @importFrom dplyr group_split
 #' @importFrom dplyr group_trim
+#' @importFrom dplyr group_vars
+#' @importFrom dplyr group_walk
 #' @importFrom dplyr grouped_df
+#' @importFrom dplyr groups
 #' @importFrom dplyr if_else
+#' @importFrom dplyr is_grouped_df
+#' @importFrom dplyr mutate_all
 #' @importFrom dplyr n_groups
+#' @importFrom dplyr rename_all
+#' @importFrom dplyr rename_at
+#' @importFrom dplyr rename_if
+#' @importFrom dplyr rowwise
+#' @importFrom dplyr same_src
+#' @importFrom dplyr select_all
+#' @importFrom dplyr select_at
+#' @importFrom dplyr select_if
+#' @importFrom dplyr summarise_all
+#' @importFrom dplyr summarise_at
+#' @importFrom dplyr vars
 #' @importFrom glue glue
 #' @importFrom lifecycle deprecated
 #' @importFrom tibble as_tibble
@@ -94,18 +125,34 @@ dplyr::anti_join
 #' @export
 dplyr::arrange
 
-#' @importFrom dplyr auto_copy
+#' @importFrom dplyr between
 #' @export
-dplyr::auto_copy
+dplyr::between
+
+#' @importFrom dplyr bind_cols
+#' @export
+dplyr::bind_cols
+
+#' @importFrom dplyr bind_rows
+#' @export
+dplyr::bind_rows
 
 #' @importFrom dplyr c_across
 #' @export
 dplyr::c_across
 
+#' @importFrom dplyr case_match
+#' @export
+dplyr::case_match
+
 #' @importFrom dplyr case_when
 #' @export
 dplyr::case_when
 
+#' @importFrom dplyr coalesce
+#' @export
+dplyr::coalesce
+
 #' @importFrom dplyr collapse
 #' @export
 dplyr::collapse
@@ -118,6 +165,10 @@ dplyr::collect
 #' @export
 dplyr::compute
 
+#' @importFrom dplyr consecutive_id
+#' @export
+dplyr::consecutive_id
+
 #' @importFrom dplyr count
 #' @export
 dplyr::count
@@ -126,6 +177,42 @@ dplyr::count
 #' @export
 dplyr::cross_join
 
+#' @importFrom dplyr cumall
+#' @export
+dplyr::cumall
+
+#' @importFrom dplyr cumany
+#' @export
+dplyr::cumany
+
+#' @importFrom dplyr cume_dist
+#' @export
+dplyr::cume_dist
+
+#' @importFrom dplyr cummean
+#' @export
+dplyr::cummean
+
+#' @importFrom dplyr cur_column
+#' @export
+dplyr::cur_column
+
+#' @importFrom dplyr cur_group
+#' @export
+dplyr::cur_group
+
+#' @importFrom dplyr cur_group_id
+#' @export
+dplyr::cur_group_id
+
+#' @importFrom dplyr cur_group_rows
+#' @export
+dplyr::cur_group_rows
+
+#' @importFrom dplyr dense_rank
+#' @export
+dplyr::dense_rank
+
 #' @importFrom dplyr desc
 #' @export
 dplyr::desc
@@ -134,22 +221,6 @@ dplyr::desc
 #' @export
 dplyr::distinct
 
-#' @importFrom dplyr do
-#' @export
-dplyr::do
-
-#' @importFrom dplyr dplyr_col_modify
-#' @export
-dplyr::dplyr_col_modify
-
-#' @importFrom dplyr dplyr_reconstruct
-#' @export
-dplyr::dplyr_reconstruct
-
-#' @importFrom dplyr dplyr_row_slice
-#' @export
-dplyr::dplyr_row_slice
-
 #' @importFrom dplyr explain
 #' @export
 dplyr::explain
@@ -165,51 +236,6 @@ dplyr::first
 #' @importFrom dplyr full_join
 #' @export
 dplyr::full_join
-
-#' @importFrom dplyr funs
-#' @export
-dplyr::funs
-
-#' @importFrom dplyr funs_
-#' @export
-dplyr::funs_
-
-#' @importFrom dplyr group_by
-#' @export
-dplyr::group_by
-
-#' @importFrom dplyr group_data
-#' @export
-dplyr::group_data
-
-#' @importFrom dplyr group_keys
-#' @export
-dplyr::group_keys
-
-#' @importFrom dplyr group_map
-#' @export
-dplyr::group_map
-
-#' @importFrom dplyr group_modify
-#' @export
-dplyr::group_modify
-
-#' @importFrom dplyr group_rows
-#' @export
-dplyr::group_rows
-
-#' @importFrom dplyr group_size
-#' @export
-dplyr::group_size
-
-#' @importFrom dplyr group_vars
-#' @export
-dplyr::group_vars
-
-#' @importFrom dplyr group_walk
-#' @export
-dplyr::group_walk
-
 #' @importFrom dplyr if_all
 #' @export
 dplyr::if_all
@@ -218,6 +244,10 @@ dplyr::if_all
 #' @export
 dplyr::if_any
 
+#' @importFrom dplyr if_else
+#' @export
+dplyr::if_else
+
 #' @importFrom dplyr inner_join
 #' @export
 dplyr::inner_join
@@ -226,10 +256,6 @@ dplyr::inner_join
 #' @export
 dplyr::intersect
 
-#' @importFrom dplyr is_grouped_df
-#' @export
-dplyr::is_grouped_df
-
 #' @importFrom dplyr join_by
 #' @export
 dplyr::join_by
@@ -250,14 +276,14 @@ dplyr::lead
 #' @export
 dplyr::left_join
 
+#' @importFrom dplyr min_rank
+#' @export
+dplyr::min_rank
+
 #' @importFrom dplyr mutate
 #' @export
 dplyr::mutate
 
-#' @importFrom dplyr mutate_all
-#' @export
-dplyr::mutate_all
-
 #' @importFrom dplyr n
 #' @export
 dplyr::n
@@ -266,6 +292,14 @@ dplyr::n
 #' @export
 dplyr::n_distinct
 
+#' @importFrom dplyr na_if
+#' @export
+dplyr::na_if
+
+#' @importFrom dplyr near
+#' @export
+dplyr::near
+
 #' @importFrom dplyr nest_by
 #' @export
 dplyr::nest_by
@@ -278,6 +312,22 @@ dplyr::nest_join
 #' @export
 dplyr::nth
 
+#' @importFrom dplyr ntile
+#' @export
+dplyr::ntile
+
+#' @importFrom dplyr order_by
+#' @export
+dplyr::order_by
+
+#' @importFrom dplyr percent_rank
+#' @export
+dplyr::percent_rank
+
+#' @importFrom dplyr pick
+#' @export
+dplyr::pick
+
 #' @importFrom dplyr pull
 #' @export
 dplyr::pull
@@ -294,18 +344,6 @@ dplyr::relocate
 #' @export
 dplyr::rename
 
-#' @importFrom dplyr rename_all
-#' @export
-dplyr::rename_all
-
-#' @importFrom dplyr rename_at
-#' @export
-dplyr::rename_at
-
-#' @importFrom dplyr rename_if
-#' @export
-dplyr::rename_if
-
 #' @importFrom dplyr rename_with
 #' @export
 dplyr::rename_with
@@ -342,14 +380,6 @@ dplyr::rows_update
 #' @export
 dplyr::rows_upsert
 
-#' @importFrom dplyr rowwise
-#' @export
-dplyr::rowwise
-
-#' @importFrom dplyr same_src
-#' @export
-dplyr::same_src
-
 #' @importFrom dplyr sample_frac
 #' @export
 dplyr::sample_frac
@@ -362,18 +392,6 @@ dplyr::sample_n
 #' @export
 dplyr::select
 
-#' @importFrom dplyr select_all
-#' @export
-dplyr::select_all
-
-#' @importFrom dplyr select_at
-#' @export
-dplyr::select_at
-
-#' @importFrom dplyr select_if
-#' @export
-dplyr::select_if
-
 #' @importFrom dplyr semi_join
 #' @export
 dplyr::semi_join
@@ -414,14 +432,6 @@ dplyr::slice_tail
 #' @export
 dplyr::summarise
 
-#' @importFrom dplyr summarise_all
-#' @export
-dplyr::summarise_all
-
-#' @importFrom dplyr summarise_at
-#' @export
-dplyr::summarise_at
-
 #' @importFrom dplyr summarize
 #' @export
 dplyr::summarize
@@ -438,6 +448,10 @@ dplyr::tally
 #' @export
 dplyr::tbl_vars
 
+#' @importFrom dplyr top_n
+#' @export
+dplyr::top_n
+
 #' @importFrom dplyr transmute
 #' @export
 dplyr::transmute
@@ -454,14 +468,74 @@ dplyr::union
 #' @export
 dplyr::union_all
 
-#' @importFrom dplyr vars
-#' @export
-dplyr::vars
-
 #' @importFrom dplyr with_groups
 #' @export
 dplyr::with_groups
 
+#' @importFrom dplyr with_order
+#' @export
+dplyr::with_order
+
+
+#' @importFrom rlang .data
+#' @export
+rlang::.data
+
+
+#' @importFrom tibble add_row
+#' @export
+tibble::add_row
+
+#' @importFrom tibble as_tibble
+#' @export
+tibble::as_tibble
+
+#' @importFrom tibble tribble
+#' @export
+tibble::tribble
+
+
+#' @importFrom tidyselect all_of
+#' @export
+tidyselect::all_of
+
+#' @importFrom tidyselect any_of
+#' @export
+tidyselect::any_of
+
+#' @importFrom tidyselect contains
+#' @export
+tidyselect::contains
+
+#' @importFrom tidyselect everything
+#' @export
+tidyselect::everything
+
+#' @importFrom tidyselect last_col
+#' @export
+tidyselect::last_col
+
+#' @importFrom tidyselect matches
+#' @export
+tidyselect::matches
+
+#' @importFrom tidyselect num_range
+#' @export
+tidyselect::num_range
+
+#' @importFrom tidyselect one_of
+#' @export
+tidyselect::one_of
+
+#' @importFrom tidyselect starts_with
+#' @export
+tidyselect::starts_with
+
+#' @importFrom tidyselect where
+#' @export
+tidyselect::where
+
+
 # Only in this package
 dplyr_mode <- FALSE
 
